==> sysdig-0.20.0-1-armv7h.pkg.tar.xz: usr/share/sysdig/chisels/topfiles_time.lua <==
--[[
Copyright (C) 2013-2014 Draios inc.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License version 2 as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
--]]

-- Chisel description
description = "Shows the top files in terms of disk usage. This chisel is compatible with containers using the sysdig -pc or -pcontainer argument, otherwise no container information will be shown."
short_description = "Top files by time"
category = "I/O"

-- Chisel argument list
args = {}

-- The number of items to show
TOP_NUMBER = 10

-- Argument notification callback
function on_set_arg(name, val)
	return false
end

-- Initialization callback
function on_init()

	-- The -pc or -pcontainer options was supplied on the cmd line
	print_container = sysdig.is_print_container_data()

	if print_container then
		chisel.exec("table_generator",
					"fd.name,container.name",
					"Filename,container.name",
					"evt.latency",
					"Time",
					"fd.type=file and evt.is_io=true",
					"" .. TOP_NUMBER,
					"time")
	else
		chisel.exec("table_generator",
					"fd.name",
					"Filename",
					"evt.latency",
					"Time",
					"fd.type=file and evt.is_io=true",
					"" .. TOP_NUMBER,
					"time")
	end

	return true
end

==> sysdig-0.24.1-1-armv7h.pkg.tar.xz: usr/share/sysdig/chisels/topfiles_time.lua <==
--[[
Copyright (C) 2013-2018 Draios Inc dba Sysdig.

This file is part of sysdig.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

--]]

-- Chisel description
description = "Shows the top files in terms of disk usage. This chisel is compatible with containers using the sysdig -pc or -pcontainer argument, otherwise no container information will be shown."
short_description = "Top files by time"
category = "I/O"

-- Chisel argument list
args = {}

-- The number of items to show
TOP_NUMBER = 10

-- Argument notification callback
function on_set_arg(name, val)
	return false
end

-- Initialization callback
function on_init()

	-- The -pc or -pcontainer options was supplied on the cmd line
	print_container = sysdig.is_print_container_data()

	if print_container then
		chisel.exec("table_generator",
					"fd.name,container.name",
					"Filename,container.name",
					"evt.latency",
					"Time",
					"fd.type=file and evt.is_io=true",
					"" .. TOP_NUMBER,
					"time")
	else
		chisel.exec("table_generator",
					"fd.name",
					"Filename",
					"evt.latency",
					"Time",
					"fd.type=file and evt.is_io=true",
					"" .. TOP_NUMBER,
					"time")
	end

	return true
end
